@@ -4,7 +4,7 @@
   CLAW is a free library without any particular aim but being useful to 
   anyone.
 
-  Copyright (C) 2005-2010 Julien Jorge
+  Copyright (C) 2005-2011 Julien Jorge
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -20,7 +20,7 @@
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-  contact: julien_jorge@yahoo.fr
+  contact: julien.jorge@gamned.org
 */
 /**
  * \file coordinate_2d.hpp
@@ -62,6 +62,9 @@ namespace claw
       void set(const value_type& _x, const value_type& _y);
       value_type distance(const self_type& p) const;
 
+      void rotate( const self_type& center, double angle );
+      double slope_angle( const self_type& to ) const;
+
       bool operator==(const self_type& vect) const;
       bool operator!=(const self_type& vect) const;
       self_type operator+(const self_type& vect) const;
