@@ -39,6 +39,8 @@
 #include <iterator>
 #include <utility>
 
+#include <cstddef>
+
 namespace claw
 {
 
@@ -109,7 +111,7 @@ namespace claw
       typedef const vertex_type  value_type;
       typedef const vertex_type& reference;
       typedef const vertex_type* const pointer;
-      typedef ptrdiff_t difference_type;
+      typedef 	ptrdiff_t difference_type;
           
       typedef std::bidirectional_iterator_tag iterator_category;
 
