@@ -4,7 +4,7 @@
   CLAW is a free library without any particular aim but being useful to 
   anyone.
 
-  Copyright (C) 2005-2010 Julien Jorge
+  Copyright (C) 2005-2011 Julien Jorge
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -20,7 +20,7 @@
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-  contact: julien_jorge@yahoo.fr
+  contact: julien.jorge@gamned.org
 */
 /**
  * \file multi_type_map.hpp
@@ -38,7 +38,7 @@ namespace claw
 {
   /**
    * \brief This class provides types and methods to allow the call of methods
-   *        recursively along the inherintance hierarchy.
+   *        for a given type in the inheritance of a multi_type_map.
    * \remark This class is to be used internally.
    *
    * Suppose we have defined the following variable
@@ -59,6 +59,14 @@ namespace claw
   template<typename ValueType, typename Map>
   class multi_type_map_wrapper;
 
+  /**
+   * \brief This class provides types and methods to allow the call of methods
+   *        recursively along the inherintance hierarchy.
+   * \remark This class is to be used internally.
+   */
+  template<typename Map>
+  class multi_type_map_helper;
+
   /**
    * \brief This class can associate values of different types to a key.
    *
@@ -90,8 +98,9 @@ namespace claw
 
   }; // class multi_type_map
 
-  /*
-   * Here is the interface of multi_type_map
+  /**
+   * \brief This class can associate values of different types to a key.
+   * \author Julien Jorge
    */
   template<typename Key, typename Head, typename Tail>
   class multi_type_map< Key, meta::type_list<Head, Tail> >:
@@ -106,6 +115,7 @@ namespace claw
     typedef multi_type_map<Key, Tail> super;
 
     friend struct multi_type_map_wrapper<value_type, self_type>;
+    friend struct multi_type_map_helper<self_type>;
 
     /** \brief This structure is used to create an iterator on the values of a
         given type. */
@@ -125,15 +135,28 @@ namespace claw
     typedef typename iterator<value_type>::const_type const_iterator_type;
 
   public:
+    template<typename ValueType>
+    void erase( typename iterator<ValueType>::type it );
+
+    template<typename ValueType>
+    std::size_t erase( const key_type& k );
+
     template<typename ValueType>
     const ValueType& get( const key_type& k ) const;
 
+    template<typename ValueType>
+    ValueType& get( const key_type& k );
+
     template<typename ValueType>
     void set( const key_type& k, const ValueType& v );
 
+    void set( const self_type& m );
+
     template<typename ValueType>
     bool exists( const key_type& k ) const;
 
+    std::size_t size() const;
+
     template<typename ValueType>
     typename iterator<ValueType>::type begin();
 
