@@ -34,6 +34,7 @@
 #include <sys/socket.h>
 #include <sys/stat.h>
 #include <netinet/in.h>
+#include <netinet/tcp.h>
 #include <netdb.h>
 #include <unistd.h>
 #include <cstring>
@@ -156,7 +157,7 @@ namespace claw
 	return ::listen(d, queue_size) != -1;
       else
 	return false;
-    } // socket_traits_unix::connect()
+    } // socket_traits_unix::listen()
 
     /*------------------------------------------------------------------------*/
     /**
