@@ -170,7 +170,7 @@ int main( int argc, char* argv[] )
           it = avl_2.end();
           while( it != avl_2.begin() )
             {
-              it--;
+              --it;
               std::cout << " "  << *it;
             }
           std::cout << std::endl;
